function norm = H1_Seminorm_Unitsquare(u)
% H1_Seminorm_Unitsquare computes the discrete H1-Seminorm of a function
% that is given on the unit square.
%
% INPUT:
% ------
% u         - Vector, u(i) is the function value in the i-th grid point 
%             (lexicographical order)
%
% OUTPUT:
% -------
% norm      - The discrete H1-Seminorm of the function induced by u
%

% Compute discretization parameter n
n = sqrt(length(u))-1;

% Reshape input, this makes it easy to ignore coodinates of the boundary
U = reshape(u,n+1,n+1);

% Compute the component of the norm for j=1
norm = sum(sum(abs(diff(U,1,1).^2)));

% Add the component for j=2
norm = norm + sum(sum(abs(diff(U,1,2).^2)));

% Compute the square root (we do not need any multiplication with h)
norm = sqrt(norm);
