function ip = L2_InnerProduct_Unitsquare(v,w)
% L2_InnerProduct_Unitsquare computes the discrete L^2 inner product of 
% two functions given by v and w (on the inner unit square on an equi-
% distant grid).
%
% INPUT:
% ------
% v         - Vector, v(i) is the function value in the i-th grid point 
%             (lexicographical order)
% w         - Vector, w(i) is the function value in the i-th grid point 
%             (lexicographical order)
%
% OUTPUT:
% -------
% ip        - The discrete L^2 inner product of v and w
%

% Compute discretization parameter n
n = sqrt(length(v))+1;

% Set the grid width h
h = 1/n;

% Compute the inner product
ip = h^2*sum(v.*w);
